==> dials_3.17.0+dfsg3.orig.tar.xz: dials-3.17.0/src/dials/array_family/flex.py <==
from __future__ import annotations

from cctbx.array_family.flex import (  # noqa: F401; lgtm
    abs,
    acos,
    arg,
    asin,
    atan,
    atan2,
    bool,
    ceil,
    compare_derivatives,
    complex_double,
    condense_as_ranges,
    conj,
    cos,
    cosh,
    cost_of_m_handle_in_af_shared,
    double,
    double_from_byte_str,
    double_range,
    empty_container_sizes_double,
    empty_container_sizes_int,
    exercise_versa_packed_u_to_flex,
    exp,
    extract_double_attributes,
    fabs,
    first_index,
    flex_argument_passing,
    float,
    float_range,
    floor,
    fmod,
    fmod_positive,
    get_random_seed,
    grid,
    hendrickson_lattman,
    histogram,
    imag,
    int,
    int_from_byte_str,
    int_range,
    integer_offsets_vs_pointers,
    intersection,
    last_index,
    linear_correlation,
    linear_interpolation,
    linear_regression,
    linear_regression_core,
    log,
    log10,
    long,
    long_range,
    mat3_double,
    max,
    max_absolute,
    max_default,
    max_index,
    mean,
    mean_and_variance,
    mean_default,
    mean_sq,
    mean_sq_weighted,
    mean_weighted,
    median,
    median_functor,
    median_statistics,
    mersenne_twister,
    miller_index,
    min,
    min_default,
    min_index,
    min_max_mean_double,
    nested_loop,
    norm,
    order,
    permutation_generator,
    polar,
    pow,
    pow2,
    product,
    py_object,
    random_bool,
    random_double,
    random_double_point_on_sphere,
    random_double_r3_rotation_matrix,
    random_double_r3_rotation_matrix_arvo_1992,
    random_double_unit_quaternion,
    random_generator,
    random_int_gaussian_distribution,
    random_permutation,
    random_selection,
    random_size_t,
    reindexing_array,
    rows,
    select,
    set_random_seed,
    show,
    show_count_stats,
    sin,
    sinh,
    size_t,
    size_t_from_byte_str,
    size_t_range,
    slice_indices,
    smart_selection,
    sort_permutation,
    sorted,
    split_lines,
    sqrt,
    std_string,
    sum,
    sum_sq,
    sym_mat3_double,
    tan,
    tanh,
    tiny_size_t_2,
    to_list,
    union,
    vec2_double,
    vec3_double,
    vec3_int,
    weighted_histogram,
    xray_scatterer,
)

# small integer types from scitbx
from scitbx.array_family.flex import (  # noqa: F401; lgtm
    int8,
    int16,
    int32,
    int64,
    uint8,
    uint16,
    uint32,
    uint64,
)

from dials.array_family.flex_ext import (  # noqa: F401; lgtm
    real,
    reflection_table_selector,
)
from dials_array_family_flex_ext import (  # noqa: F401; lgtm
    Binner,
    PixelListShoeboxCreator,
    int6,
    observation,
    reflection_table,
    reflection_table_to_list_of_reflections,
    shoebox,
)

==> dials_3.25.0+dfsg3.orig.tar.xz: dials-3.25.0/src/dials/array_family/flex.py <==
from __future__ import annotations

from cctbx.array_family.flex import (  # noqa: F401
    abs,
    acos,
    arg,
    asin,
    atan,
    atan2,
    bool,
    ceil,
    compare_derivatives,
    complex_double,
    condense_as_ranges,
    conj,
    cos,
    cosh,
    cost_of_m_handle_in_af_shared,
    double,
    double_from_byte_str,
    double_range,
    empty_container_sizes_double,
    empty_container_sizes_int,
    exercise_versa_packed_u_to_flex,
    exp,
    extract_double_attributes,
    fabs,
    first_index,
    flex_argument_passing,
    float,
    float_range,
    floor,
    fmod,
    fmod_positive,
    get_random_seed,
    grid,
    hendrickson_lattman,
    histogram,
    imag,
    int,
    int_from_byte_str,
    int_range,
    integer_offsets_vs_pointers,
    intersection,
    last_index,
    linear_correlation,
    linear_interpolation,
    linear_regression,
    linear_regression_core,
    log,
    log10,
    long,
    long_range,
    mat3_double,
    max,
    max_absolute,
    max_default,
    max_index,
    mean,
    mean_and_variance,
    mean_default,
    mean_sq,
    mean_sq_weighted,
    mean_weighted,
    median,
    median_functor,
    median_statistics,
    mersenne_twister,
    miller_index,
    min,
    min_default,
    min_index,
    min_max_mean_double,
    nested_loop,
    norm,
    order,
    permutation_generator,
    polar,
    pow,
    pow2,
    product,
    py_object,
    random_bool,
    random_double,
    random_double_point_on_sphere,
    random_double_r3_rotation_matrix,
    random_double_r3_rotation_matrix_arvo_1992,
    random_double_unit_quaternion,
    random_generator,
    random_int_gaussian_distribution,
    random_permutation,
    random_selection,
    random_size_t,
    reindexing_array,
    rows,
    select,
    set_random_seed,
    show,
    show_count_stats,
    sin,
    sinh,
    size_t,
    size_t_from_byte_str,
    size_t_range,
    slice_indices,
    smart_selection,
    sort_permutation,
    sorted,
    split_lines,
    sqrt,
    std_string,
    sum,
    sum_sq,
    sym_mat3_double,
    tan,
    tanh,
    tiny_size_t_2,
    to_list,
    union,
    vec2_double,
    vec3_double,
    vec3_int,
    weighted_histogram,
    xray_scatterer,
)

# small integer types from scitbx
from scitbx.array_family.flex import (  # noqa: F401
    int8,
    int16,
    int32,
    int64,
    uint8,
    uint16,
    uint32,
    uint64,
)

from dials.array_family.flex_ext import (  # noqa: F401
    real,
    reflection_table_selector,
)
from dials_array_family_flex_ext import (  # noqa: F401
    Binner,
    PixelListShoeboxCreator,
    int6,
    observation,
    reflection_table,
    reflection_table_to_list_of_reflections,
    shoebox,
)
